@@ -29,6 +29,7 @@ import java.util.ArrayList;
 import java.util.Enumeration;
 import java.util.HashMap;
 import java.util.HashSet;
+import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
@@ -43,6 +44,8 @@ import java.util.concurrent.TimeUnit;
 
 import javax.management.MalformedObjectNameException;
 import javax.management.ObjectName;
+import javax.net.ssl.SSLEngine;
+import javax.net.ssl.SSLParameters;
 
 import org.apache.juli.logging.Log;
 import org.apache.tomcat.util.ExceptionUtils;
@@ -52,6 +55,7 @@ import org.apache.tomcat.util.collections.SynchronizedStack;
 import org.apache.tomcat.util.modeler.Registry;
 import org.apache.tomcat.util.net.Acceptor.AcceptorState;
 import org.apache.tomcat.util.net.SSLHostConfigCertificate.StoreType;
+import org.apache.tomcat.util.net.openssl.ciphers.Cipher;
 import org.apache.tomcat.util.res.StringManager;
 import org.apache.tomcat.util.threads.LimitLatch;
 import org.apache.tomcat.util.threads.ResizableExecutor;
@@ -63,6 +67,9 @@ import org.apache.tomcat.util.threads.VirtualThreadExecutor;
 /**
  * @param <S> The type used by the socket wrapper associated with this endpoint. Might be the same as U.
  * @param <U> The type of the underlying socket used by this endpoint. Might be the same as S.
+ *
+ * @author Mladen Turk
+ * @author Remy Maucherat
  */
 public abstract class AbstractEndpoint<S, U> {
 
@@ -219,16 +226,34 @@ public abstract class AbstractEndpoint<S, U> {
         return new HashSet<>(connections.values());
     }
 
-    // ----------------------------------------------------------------- Properties
+    private SSLImplementation sslImplementation = null;
 
-    private boolean strictSni = true;
-
-    public boolean getStrictSni() {
-        return strictSni;
+    public SSLImplementation getSslImplementation() {
+        return sslImplementation;
     }
 
-    public void setStrictSni(boolean strictSni) {
-        this.strictSni = strictSni;
+
+    // ----------------------------------------------------------------- Properties
+
+    private String sslImplementationName = null;
+
+    public String getSslImplementationName() {
+        return sslImplementationName;
+    }
+
+    public void setSslImplementationName(String s) {
+        this.sslImplementationName = s;
+    }
+
+
+    private int sniParseLimit = 64 * 1024;
+
+    public int getSniParseLimit() {
+        return sniParseLimit;
+    }
+
+    public void setSniParseLimit(int sniParseLimit) {
+        this.sniParseLimit = sniParseLimit;
     }
 
 
@@ -367,9 +392,46 @@ public abstract class AbstractEndpoint<S, U> {
      *
      * @param sslHostConfig The SSLHostConfig for which the SSLContext should be created
      *
-     * @throws Exception If the SSLContext cannot be created for the given SSLHostConfig
+     * @throws IllegalArgumentException If the SSLContext cannot be created for the given SSLHostConfig
      */
-    protected abstract void createSSLContext(SSLHostConfig sslHostConfig) throws Exception;
+    protected void createSSLContext(SSLHostConfig sslHostConfig) throws IllegalArgumentException {
+
+        // HTTP/2 does not permit optional certificate authentication with any
+        // version of TLS.
+        if (sslHostConfig.getCertificateVerification().isOptional() && negotiableProtocols.contains("h2")) {
+            getLog().warn(sm.getString("sslHostConfig.certificateVerificationWithHttp2", sslHostConfig.getHostName()));
+        }
+
+        boolean firstCertificate = true;
+        for (SSLHostConfigCertificate certificate : sslHostConfig.getCertificates(true)) {
+            SSLUtil sslUtil = sslImplementation.getSSLUtil(certificate);
+            if (firstCertificate) {
+                firstCertificate = false;
+                sslHostConfig.setEnabledProtocols(sslUtil.getEnabledProtocols());
+                sslHostConfig.setEnabledCiphers(sslUtil.getEnabledCiphers());
+            }
+
+            SSLContext sslContext = certificate.getSslContext();
+            SSLContext sslContextGenerated = certificate.getSslContextGenerated();
+            // Generate the SSLContext from configuration unless (e.g. embedded) an SSLContext has been provided.
+            // Need to handle both initial configuration and reload.
+            // Initial, SSLContext provided - sslContext will be non-null and sslContextGenerated will be null
+            // Initial, SSLContext not provided - sslContext null and sslContextGenerated will be null
+            // Reload, SSLContext provided - sslContext will be non-null and sslContextGenerated will be null
+            // Reload, SSLContext not provided - sslContext non-null and equal to sslContextGenerated
+            if (sslContext == null || sslContext == sslContextGenerated) {
+                try {
+                    sslContext = sslUtil.createSSLContext(negotiableProtocols);
+                } catch (Exception e) {
+                    throw new IllegalArgumentException(sm.getString("endpoint.errorCreatingSSLContext"), e);
+                }
+
+                certificate.setSslContextGenerated(sslContext);
+            }
+
+            logCertificate(certificate);
+        }
+    }
 
 
     protected void logCertificate(SSLHostConfigCertificate certificate) {
@@ -387,14 +449,8 @@ public abstract class AbstractEndpoint<S, U> {
             if (keyAlias == null) {
                 keyAlias = SSLUtilBase.DEFAULT_KEY_ALIAS;
             }
-            String keystoreFile;
-            if (certificate.getCertificateKeystoreInternal() != null) {
-                // Keystore was set directly. Original location is unknown.
-                keystoreFile = sm.getString("endpoint.tls.info.cert.keystore.direct");
-            } else {
-                keystoreFile = certificate.getCertificateKeystoreFile();
-            }
-            certificateInfo = sm.getString("endpoint.tls.info.cert.keystore", keystoreFile, keyAlias);
+            certificateInfo =
+                    sm.getString("endpoint.tls.info.cert.keystore", certificate.getCertificateKeystoreFile(), keyAlias);
         }
 
         String trustStoreSource = sslHostConfig.getTruststoreFile();
@@ -451,6 +507,105 @@ public abstract class AbstractEndpoint<S, U> {
         return sb.toString();
     }
 
+    protected SSLEngine createSSLEngine(String sniHostName, List<Cipher> clientRequestedCiphers,
+            List<String> clientRequestedApplicationProtocols) {
+        SSLHostConfig sslHostConfig = getSSLHostConfig(sniHostName);
+
+        SSLHostConfigCertificate certificate = selectCertificate(sslHostConfig, clientRequestedCiphers);
+
+        SSLContext sslContext = certificate.getSslContext();
+        if (sslContext == null) {
+            throw new IllegalStateException(sm.getString("endpoint.jsse.noSslContext", sniHostName));
+        }
+
+        SSLEngine engine = sslContext.createSSLEngine();
+        engine.setUseClientMode(false);
+        engine.setEnabledCipherSuites(sslHostConfig.getEnabledCiphers());
+        engine.setEnabledProtocols(sslHostConfig.getEnabledProtocols());
+
+        SSLParameters sslParameters = engine.getSSLParameters();
+        sslParameters.setUseCipherSuitesOrder(sslHostConfig.getHonorCipherOrder());
+        if (clientRequestedApplicationProtocols != null && !clientRequestedApplicationProtocols.isEmpty() &&
+                !negotiableProtocols.isEmpty()) {
+            // Only try to negotiate if both client and server have at least
+            // one protocol in common
+            // Note: Tomcat does not explicitly negotiate http/1.1
+            List<String> commonProtocols = new ArrayList<>(negotiableProtocols);
+            commonProtocols.retainAll(clientRequestedApplicationProtocols);
+            if (!commonProtocols.isEmpty()) {
+                String[] commonProtocolsArray = commonProtocols.toArray(new String[0]);
+                sslParameters.setApplicationProtocols(commonProtocolsArray);
+            }
+        }
+        switch (sslHostConfig.getCertificateVerification()) {
+            case NONE:
+                sslParameters.setNeedClientAuth(false);
+                sslParameters.setWantClientAuth(false);
+                break;
+            case OPTIONAL:
+            case OPTIONAL_NO_CA:
+                sslParameters.setWantClientAuth(true);
+                break;
+            case REQUIRED:
+                sslParameters.setNeedClientAuth(true);
+                break;
+        }
+        // The getter (at least in OpenJDK and derivatives) returns a defensive copy
+        engine.setSSLParameters(sslParameters);
+
+        return engine;
+    }
+
+
+    private SSLHostConfigCertificate selectCertificate(SSLHostConfig sslHostConfig, List<Cipher> clientCiphers) {
+
+        Set<SSLHostConfigCertificate> certificates = sslHostConfig.getCertificates(true);
+        if (certificates.size() == 1) {
+            return certificates.iterator().next();
+        }
+
+        LinkedHashSet<Cipher> serverCiphers = sslHostConfig.getCipherList();
+
+        List<Cipher> candidateCiphers = new ArrayList<>();
+        if (sslHostConfig.getHonorCipherOrder()) {
+            candidateCiphers.addAll(serverCiphers);
+            candidateCiphers.retainAll(clientCiphers);
+        } else {
+            candidateCiphers.addAll(clientCiphers);
+            candidateCiphers.retainAll(serverCiphers);
+        }
+
+        for (Cipher candidate : candidateCiphers) {
+            for (SSLHostConfigCertificate certificate : certificates) {
+                if (certificate.getType().isCompatibleWith(candidate.getAu())) {
+                    return certificate;
+                }
+            }
+        }
+
+        // No matches. Just return the first certificate. The handshake will
+        // then fail due to no matching ciphers.
+        return certificates.iterator().next();
+    }
+
+
+    protected void initialiseSsl() throws Exception {
+        if (isSSLEnabled()) {
+            sslImplementation = SSLImplementation.getInstance(getSslImplementationName());
+
+            for (SSLHostConfig sslHostConfig : sslHostConfigs.values()) {
+                createSSLContext(sslHostConfig);
+            }
+
+            // Validate default SSLHostConfigName
+            if (sslHostConfigs.get(getDefaultSSLHostConfigName()) == null) {
+                throw new IllegalArgumentException(
+                        sm.getString("endpoint.noSslHostConfig", getDefaultSSLHostConfigName(), getName()));
+            }
+
+        }
+    }
+
 
     protected void destroySsl() throws Exception {
         if (isSSLEnabled()) {
@@ -519,22 +674,6 @@ public abstract class AbstractEndpoint<S, U> {
     }
 
 
-    /**
-     * Check if two host names share the same SSLHostConfig.
-     *
-     * @param sniHostName the host name from SNI, null if SNI is not in use
-     * @param protocolHostName the host name from the protocol
-     * @return true if SNI is not checked, if the SNI host name matches the protocol host name,
-     *    if both host names use the same SSLHostConfig configuration, if there is no SNI and the
-     *    protocol host name uses the default SSLHostConfig configuration, and false otherwise
-     */
-    public boolean checkSni(String sniHostName, String protocolHostName) {
-        return (!strictSni || !isSSLEnabled()
-                || (sniHostName != null && sniHostName.equalsIgnoreCase(protocolHostName))
-                || getSSLHostConfig(sniHostName) == getSSLHostConfig(protocolHostName));
-    }
-
-
     /**
      * Has the user requested that send file be used where possible?
      */
@@ -1043,19 +1182,6 @@ public abstract class AbstractEndpoint<S, U> {
     }
 
 
-    /**
-     * Always returns {@code false}.
-     *
-     * @return Always {@code false}
-     *
-     * @deprecated This code will be removed in Tomcat 11 onwards
-     */
-    @Deprecated
-    public boolean getDeferAccept() {
-        return false;
-    }
-
-
     /**
      * The default behavior is to identify connectors uniquely with address and port. However, certain connectors are
      * not using that and need some other identifier, which then can be used as a replacement.
@@ -1138,8 +1264,8 @@ public abstract class AbstractEndpoint<S, U> {
             } else {
                 return IntrospectionUtils.setProperty(this, name, value, false);
             }
-        } catch (Exception e) {
-            getLog().error(sm.getString("endpoint.setAttributeError", name, value), e);
+        } catch (Exception x) {
+            getLog().error(sm.getString("endpoint.setAttributeError", name, value), x);
             return false;
         }
     }
@@ -1227,9 +1353,8 @@ public abstract class AbstractEndpoint<S, U> {
         Executor executor = this.executor;
         if (executor != null && internalExecutor) {
             this.executor = null;
-            if (executor instanceof ThreadPoolExecutor) {
+            if (executor instanceof ThreadPoolExecutor tpe) {
                 // this is our internal one, so we need to shut it down
-                ThreadPoolExecutor tpe = (ThreadPoolExecutor) executor;
                 tpe.shutdownNow();
                 long timeout = getExecutorTerminationTimeoutMillis();
                 if (timeout > 0) {
@@ -1262,9 +1387,7 @@ public abstract class AbstractEndpoint<S, U> {
         try {
             localAddress = getLocalAddress();
         } catch (IOException ioe) {
-            if (getLog().isDebugEnabled()) {
-                getLog().debug(sm.getString("endpoint.debug.unlock.localFail", getName()), ioe);
-            }
+            getLog().debug(sm.getString("endpoint.debug.unlock.localFail", getName()), ioe);
         }
         if (localAddress == null) {
             getLog().warn(sm.getString("endpoint.debug.unlock.localNone", getName()));
@@ -1419,7 +1542,17 @@ public abstract class AbstractEndpoint<S, U> {
 
     public abstract void bind() throws Exception;
 
-    public abstract void unbind() throws Exception;
+    public void unbind() throws Exception {
+        for (SSLHostConfig sslHostConfig : sslHostConfigs.values()) {
+            for (SSLHostConfigCertificate certificate : sslHostConfig.getCertificates()) {
+                /*
+                 * Only remove any generated SSLContext. If the SSLContext was provided it is left in place in case the
+                 * endpoint is re-started.
+                 */
+                certificate.setSslContextGenerated(null);
+            }
+        }
+    }
 
     public abstract void startInternal() throws Exception;
 
