@@ -40,12 +40,9 @@ import static org.apache.catalina.startup.SimpleHttpClient.CRLF;
 import org.apache.catalina.Context;
 import org.apache.catalina.Wrapper;
 import org.apache.catalina.core.StandardContext;
-import org.apache.catalina.filters.FailedRequestFilter;
 import org.apache.catalina.startup.Tomcat;
 import org.apache.catalina.startup.TomcatBaseTest;
 import org.apache.tomcat.util.buf.ByteChunk;
-import org.apache.tomcat.util.descriptor.web.FilterDef;
-import org.apache.tomcat.util.descriptor.web.FilterMap;
 import org.apache.tomcat.util.scan.StandardJarScanner;
 
 
@@ -64,47 +61,66 @@ public class TestParameterLimitValve extends TomcatBaseTest {
         Tomcat.addServlet(ctx, "snoop", new SnoopServlet());
         ctx.addServletMappingDecoded("/special/endpoint", "snoop");
 
-        addFailedRequestFilter(ctx);
-
         tomcat.start();
 
-        int rc = getUrl("http://localhost:" + getPort() + "/special/endpoint?param1=value1&param2=value2&param3=value3",
-                new ByteChunk(), null);
+        int rc = getUrl("http://localhost:" + getPort() +
+                "/special/endpoint?param1=value1&param2=value2&param3=value3",
+            new ByteChunk(), null);
         Assert.assertEquals(400, rc);
 
-        rc = getUrl("http://localhost:" + getPort() + "/special/endpoint?param1=value1&param2=value2", new ByteChunk(),
-                null);
+        rc = getUrl("http://localhost:" + getPort() + "/special/endpoint?param1=value1&param2=value2",
+            new ByteChunk(), null);
         Assert.assertEquals(200, rc);
 
-        byte[] body = ("POST / HTTP/1.1" + CRLF + "Host: localhost:" + getPort() + CRLF + "Connection: close" + CRLF +
-                "Transfer-Encoding: chunked" + CRLF + "Content-Type: application/x-www-form-urlencoded" + CRLF + CRLF +
-                "param1=value1&param2=value2&param3=value3" + CRLF).getBytes(StandardCharsets.UTF_8);
+        byte[] body = ("POST / HTTP/1.1" + CRLF +
+            "Host: localhost:" + getPort() + CRLF +
+            "Connection: close" + CRLF +
+            "Transfer-Encoding: chunked" + CRLF +
+            "Content-Type: application/x-www-form-urlencoded" + CRLF +
+            CRLF +
+            "param1=value1&param2=value2&param3=value3" + CRLF).getBytes(StandardCharsets.UTF_8);
 
-        rc = postUrl(body, "http://localhost:" + getPort() + "/special/endpoint", new ByteChunk(), null);
+        rc = postUrl(body,"http://localhost:" + getPort() + "/special/endpoint",
+            new ByteChunk(), null);
 
         Assert.assertEquals(400, rc);
 
-        body = ("POST / HTTP/1.1" + CRLF + "Host: localhost:" + getPort() + CRLF + "Connection: close" + CRLF +
-                "Transfer-Encoding: chunked" + CRLF + "Content-Type: application/x-www-form-urlencoded" + CRLF + CRLF +
-                "param1=value1&param2=value2" + CRLF).getBytes(StandardCharsets.UTF_8);
+        body = ("POST / HTTP/1.1" + CRLF +
+            "Host: localhost:" + getPort() + CRLF +
+            "Connection: close" + CRLF +
+            "Transfer-Encoding: chunked" + CRLF +
+            "Content-Type: application/x-www-form-urlencoded" + CRLF +
+            CRLF +
+            "param1=value1&param2=value2" + CRLF).getBytes(StandardCharsets.UTF_8);
 
-        rc = postUrl(body, "http://localhost:" + getPort() + "/special/endpoint", new ByteChunk(), null);
+        rc = postUrl(body, "http://localhost:" + getPort() + "/special/endpoint",
+            new ByteChunk(), null);
 
         Assert.assertEquals(200, rc);
 
-        body = ("POST / HTTP/1.1" + CRLF + "Host: localhost:" + getPort() + CRLF + "Connection: close" + CRLF +
-                "Transfer-Encoding: chunked" + CRLF + "Content-Type: application/x-www-form-urlencoded" + CRLF + CRLF +
-                "param1=value1&param2=value2" + CRLF).getBytes(StandardCharsets.UTF_8);
+        body = ("POST / HTTP/1.1" + CRLF +
+            "Host: localhost:" + getPort() + CRLF +
+            "Connection: close" + CRLF +
+            "Transfer-Encoding: chunked" + CRLF +
+            "Content-Type: application/x-www-form-urlencoded" + CRLF +
+            CRLF +
+            "param1=value1&param2=value2" + CRLF).getBytes(StandardCharsets.UTF_8);
 
-        rc = postUrl(body, "http://localhost:" + getPort() + "/special/endpoint?param3=value3", new ByteChunk(), null);
+        rc = postUrl(body, "http://localhost:" + getPort() + "/special/endpoint?param3=value3",
+            new ByteChunk(), null);
 
         Assert.assertEquals(400, rc);
 
-        body = ("POST / HTTP/1.1" + CRLF + "Host: localhost:" + getPort() + CRLF + "Connection: close" + CRLF +
-                "Transfer-Encoding: chunked" + CRLF + "Content-Type: application/x-www-form-urlencoded" + CRLF + CRLF +
-                "param1=value1" + CRLF).getBytes(StandardCharsets.UTF_8);
+        body = ("POST / HTTP/1.1" + CRLF +
+            "Host: localhost:" + getPort() + CRLF +
+            "Connection: close" + CRLF +
+            "Transfer-Encoding: chunked" + CRLF +
+            "Content-Type: application/x-www-form-urlencoded" + CRLF +
+            CRLF +
+            "param1=value1" + CRLF).getBytes(StandardCharsets.UTF_8);
 
-        rc = postUrl(body, "http://localhost:" + getPort() + "/special/endpoint?param2=value2", new ByteChunk(), null);
+        rc = postUrl(body, "http://localhost:" + getPort() + "/special/endpoint?param2=value2",
+            new ByteChunk(), null);
 
         Assert.assertEquals(200, rc);
 
@@ -126,12 +142,11 @@ public class TestParameterLimitValve extends TomcatBaseTest {
         Tomcat.addServlet(ctx, "snoop", new SnoopServlet());
         ctx.addServletMappingDecoded("/special===", "snoop");
 
-        addFailedRequestFilter(ctx);
-
         tomcat.start();
 
-        int rc = getUrl("http://localhost:" + getPort() + "/special===?param1=value1&param2=value2", new ByteChunk(),
-                null);
+        int rc = getUrl("http://localhost:" + getPort() +
+                "/special===?param1=value1&param2=value2",
+            new ByteChunk(), null);
 
         Assert.assertEquals(200, rc);
     }
@@ -149,13 +164,11 @@ public class TestParameterLimitValve extends TomcatBaseTest {
         Tomcat.addServlet(ctx, "snoop", new SnoopServlet());
         ctx.addServletMappingDecoded("/special endpoint", "snoop");
 
-        addFailedRequestFilter(ctx);
-
         tomcat.start();
 
-        int rc = getUrl(
-                "http://localhost:" + getPort() + "/special%20endpoint?param1=value1&param2=value2&param3=value3",
-                new ByteChunk(), null);
+        int rc = getUrl("http://localhost:" + getPort() +
+                "/special%20endpoint?param1=value1&param2=value2&param3=value3",
+            new ByteChunk(), null);
 
         Assert.assertEquals(400, rc);
     }
@@ -170,8 +183,7 @@ public class TestParameterLimitValve extends TomcatBaseTest {
 
         ParameterLimitValve parameterLimitValve = new ParameterLimitValve();
         ctx.getPipeline().addValve(parameterLimitValve);
-        parameterLimitValve
-                .setUrlPatternLimits("/special/.*=2" + CRLF + "/special2/.*=3" + CRLF + "/my/special/url1=1");
+        parameterLimitValve.setUrlPatternLimits("/special/.*=2" + CRLF + "/special2/.*=3" + CRLF + "/my/special/url1=1");
 
         Tomcat.addServlet(ctx, "snoop", new SnoopServlet());
         ctx.addServletMappingDecoded("/special/endpoint", "snoop");
@@ -179,41 +191,46 @@ public class TestParameterLimitValve extends TomcatBaseTest {
         ctx.addServletMappingDecoded("/my/special/url1", "snoop");
         ctx.addServletMappingDecoded("/my/special/url2", "snoop");
 
-        addFailedRequestFilter(ctx);
-
         tomcat.start();
 
-        int rc = getUrl("http://localhost:" + getPort() + "/special/endpoint?param1=value1&param2=value2&param3=value3",
-                new ByteChunk(), null);
+        int rc = getUrl("http://localhost:" + getPort() +
+                "/special/endpoint?param1=value1&param2=value2&param3=value3",
+            new ByteChunk(), null);
         Assert.assertEquals(400, rc);
 
-        rc = getUrl(
-                "http://localhost:" + getPort() +
-                        "/special2/endpoint?param1=value1&param2=value2&param3=value3&param4=value4",
-                new ByteChunk(), null);
+        rc = getUrl("http://localhost:" + getPort() +
+                "/special2/endpoint?param1=value1&param2=value2&param3=value3&param4=value4",
+            new ByteChunk(), null);
         Assert.assertEquals(400, rc);
 
-        rc = getUrl("http://localhost:" + getPort() + "/my/special/url1?param1=value1&param2=value2", new ByteChunk(),
-                null);
+        rc = getUrl("http://localhost:" + getPort() +
+                "/my/special/url1?param1=value1&param2=value2",
+            new ByteChunk(), null);
         Assert.assertEquals(400, rc);
 
-        rc = getUrl("http://localhost:" + getPort() + "/my/special/url2?param1=value1&param2=value2&param3=value3",
-                new ByteChunk(), null);
+        rc = getUrl("http://localhost:" + getPort() +
+                "/my/special/url2?param1=value1&param2=value2&param3=value3",
+            new ByteChunk(), null);
         Assert.assertEquals(400, rc);
 
-        rc = getUrl("http://localhost:" + getPort() + "/special/endpoint?param1=value1&param2=value2", new ByteChunk(),
-                null);
+        rc = getUrl("http://localhost:" + getPort() +
+                "/special/endpoint?param1=value1&param2=value2",
+            new ByteChunk(), null);
         Assert.assertEquals(200, rc);
 
-        rc = getUrl("http://localhost:" + getPort() + "/special2/endpoint?param1=value1&param2=value2&param3=value3",
-                new ByteChunk(), null);
+        rc = getUrl("http://localhost:" + getPort() +
+                "/special2/endpoint?param1=value1&param2=value2&param3=value3",
+            new ByteChunk(), null);
         Assert.assertEquals(200, rc);
 
-        rc = getUrl("http://localhost:" + getPort() + "/my/special/url1?param1=value1", new ByteChunk(), null);
+        rc = getUrl("http://localhost:" + getPort() +
+                "/my/special/url1?param1=value1",
+            new ByteChunk(), null);
         Assert.assertEquals(200, rc);
 
-        rc = getUrl("http://localhost:" + getPort() + "/my/special/url2?param1=value1&param2=value2", new ByteChunk(),
-                null);
+        rc = getUrl("http://localhost:" + getPort() +
+                "/my/special/url2?param1=value1&param2=value2",
+            new ByteChunk(), null);
         Assert.assertEquals(200, rc);
     }
 
@@ -232,12 +249,10 @@ public class TestParameterLimitValve extends TomcatBaseTest {
         Tomcat.addServlet(ctx, "snoop", new SnoopServlet());
         ctx.addServletMappingDecoded("/other/endpoint", "snoop");
 
-        addFailedRequestFilter(ctx);
-
         tomcat.start();
 
         int rc = getUrl("http://localhost:" + getPort() + "/other/endpoint?param1=value1&param2=value2",
-                new ByteChunk(), null);
+            new ByteChunk(), null);
 
         Assert.assertEquals(400, rc);
     }
@@ -265,16 +280,12 @@ public class TestParameterLimitValve extends TomcatBaseTest {
         Tomcat.addServlet(ctx, "snoop", new SnoopServlet());
         ctx.addServletMappingDecoded("/api/test", "snoop");
 
-        addFailedRequestFilter(ctx);
-
         tomcat.start();
 
-        int rc = getUrl("http://localhost:" + getPort() + "/api/test?param1=value1&param2=value2", new ByteChunk(),
-                null);
+        int rc = getUrl("http://localhost:" + getPort() + "/api/test?param1=value1&param2=value2", new ByteChunk(), null);
         Assert.assertEquals(200, rc);
 
-        rc = getUrl("http://localhost:" + getPort() + "/api/test?param1=value1&param2=value2&param3=value3",
-                new ByteChunk(), null);
+        rc = getUrl("http://localhost:" + getPort() + "/api/test?param1=value1&param2=value2&param3=value3", new ByteChunk(), null);
         Assert.assertEquals(400, rc);
     }
 
@@ -295,12 +306,9 @@ public class TestParameterLimitValve extends TomcatBaseTest {
         Tomcat.addServlet(ctx, "snoop", new SnoopServlet());
         ctx.addServletMappingDecoded("/api/test", "snoop");
 
-        addFailedRequestFilter(ctx);
-
         tomcat.start();
 
-        int rc = getUrl("http://localhost:" + getPort() + "/api/test?param1=value1&param2=value2", new ByteChunk(),
-                null);
+        int rc = getUrl("http://localhost:" + getPort() + "/api/test?param1=value1&param2=value2", new ByteChunk(), null);
         Assert.assertEquals(200, rc);
     }
 
@@ -329,23 +337,18 @@ public class TestParameterLimitValve extends TomcatBaseTest {
         ctx.addServletMappingDecoded("/api/test", "snoop");
         ctx.addServletMappingDecoded("/admin/test", "snoop");
 
-        addFailedRequestFilter(ctx);
-
         tomcat.start();
 
-        int rc = getUrl("http://localhost:" + getPort() + "/api/test?param1=value1&param2=value2", new ByteChunk(),
-                null);
+        int rc = getUrl("http://localhost:" + getPort() + "/api/test?param1=value1&param2=value2", new ByteChunk(), null);
         Assert.assertEquals(200, rc);
 
         rc = getUrl("http://localhost:" + getPort() + "/admin/test?param1=value1&param2=value2", new ByteChunk(), null);
         Assert.assertEquals(200, rc);
 
-        rc = getUrl("http://localhost:" + getPort() + "/api/test?param1=value1&param2=value2&param3=value3",
-                new ByteChunk(), null);
+        rc = getUrl("http://localhost:" + getPort() + "/api/test?param1=value1&param2=value2&param3=value3", new ByteChunk(), null);
         Assert.assertEquals(400, rc);
 
-        rc = getUrl("http://localhost:" + getPort() + "/admin/test?param1=value1&param2=value2&param3=value3",
-                new ByteChunk(), null);
+        rc = getUrl("http://localhost:" + getPort() + "/admin/test?param1=value1&param2=value2&param3=value3", new ByteChunk(), null);
         Assert.assertEquals(400, rc);
     }
 
@@ -362,17 +365,17 @@ public class TestParameterLimitValve extends TomcatBaseTest {
         Tomcat.addServlet(ctx, "snoop", new SnoopServlet());
         ctx.addServletMappingDecoded("/special/endpoint", "snoop");
 
-        addFailedRequestFilter(ctx);
-
         tomcat.start();
 
-        int rc = getUrl("http://localhost:" + getPort() + "/special/endpoint?param1=value1&param2=value2&param3=value3",
-                new ByteChunk(), null);
+        int rc = getUrl("http://localhost:" + getPort() +
+                "/special/endpoint?param1=value1&param2=value2&param3=value3",
+            new ByteChunk(), null);
 
         Assert.assertEquals(400, rc);
 
-        rc = getUrl("http://localhost:" + getPort() + "/special/endpoint?param1=value1&param2=value2", new ByteChunk(),
-                null);
+        rc = getUrl("http://localhost:" + getPort() +
+                "/special/endpoint?param1=value1&param2=value2",
+            new ByteChunk(), null);
 
         Assert.assertEquals(200, rc);
     }
@@ -412,24 +415,23 @@ public class TestParameterLimitValve extends TomcatBaseTest {
         Tomcat.addServlet(ctx3, "snoop", new SnoopServlet());
         ctx3.addServletMappingDecoded("/special/endpoint", "snoop");
 
-        addFailedRequestFilter(ctx1);
-        addFailedRequestFilter(ctx2);
-        addFailedRequestFilter(ctx3);
-
         tomcat.start();
 
         int rc = getUrl("http://localhost:" + getPort() +
-                "/context1/special/endpoint?param1=value1&param2=value2&param3=value3", new ByteChunk(), null);
+                "/context1/special/endpoint?param1=value1&param2=value2&param3=value3",
+            new ByteChunk(), null);
 
         Assert.assertEquals(200, rc);
 
         rc = getUrl("http://localhost:" + getPort() +
-                "/context2/special/endpoint?param1=value1&param2=value2&param3=value3", new ByteChunk(), null);
+                "/context2/special/endpoint?param1=value1&param2=value2&param3=value3",
+            new ByteChunk(), null);
 
         Assert.assertEquals(400, rc);
 
-        rc = getUrl("http://localhost:" + getPort() + "/context3/special/endpoint?param1=value1&param2=value2",
-                new ByteChunk(), null);
+        rc = getUrl("http://localhost:" + getPort() +
+                "/context3/special/endpoint?param1=value1&param2=value2",
+            new ByteChunk(), null);
 
         Assert.assertEquals(400, rc);
     }
@@ -480,8 +482,6 @@ public class TestParameterLimitValve extends TomcatBaseTest {
         w.setMultipartConfigElement(new MultipartConfigElement(""));
         ctx.addServletMappingDecoded("/upload/*", "multipart");
 
-        addFailedRequestFilter(ctx);
-
         tomcat.start();
 
         // Construct a simple multipart body with two parts
@@ -506,147 +506,11 @@ public class TestParameterLimitValve extends TomcatBaseTest {
             Assert.assertEquals(HttpServletResponse.SC_OK, rc);
         } else {
             Assert.assertTrue(Integer.toString(rc),
-                    rc == HttpServletResponse.SC_BAD_REQUEST || rc == HttpServletResponse.SC_REQUEST_ENTITY_TOO_LARGE ||
-                    rc == HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
+                    rc == HttpServletResponse.SC_BAD_REQUEST || rc == HttpServletResponse.SC_REQUEST_ENTITY_TOO_LARGE);
         }
     }
 
 
-    @Test
-    public void testMaxParameterCountLimitExceeded01_02_00_00() throws Exception {
-        doTestMaxParameterCountLimitExceeded(1, 2, 0, 0, false);
-    }
-
-
-    @Test
-    public void testMaxParameterCountLimitExceeded01_00_02_00() throws Exception {
-        doTestMaxParameterCountLimitExceeded(1, 0, 2, 0, false);
-    }
-
-
-    @Test
-    public void testMaxParameterCountLimitExceeded01_00_00_02() throws Exception {
-        doTestMaxParameterCountLimitExceeded(1, 0, 0, 2, false);
-    }
-
-
-    @Test
-    public void testMaxParameterCountLimitExceeded01_01_00_00() throws Exception {
-        doTestMaxParameterCountLimitExceeded(1, 1, 0, 0, true);
-    }
-
-
-    @Test
-    public void testMaxParameterCountLimitExceeded01_00_01_00() throws Exception {
-        doTestMaxParameterCountLimitExceeded(1, 0, 1, 0, true);
-    }
-
-
-    @Test
-    public void testMaxParameterCountLimitExceeded01_00_00_01() throws Exception {
-        doTestMaxParameterCountLimitExceeded(1, 0, 0, 1, true);
-    }
-
-
-    @Test
-    public void testMaxParameterCountLimitExceeded02_01_01_00() throws Exception {
-        doTestMaxParameterCountLimitExceeded(2, 1, 1, 0, true);
-    }
-
-
-    @Test
-    public void testMaxParameterCountLimitExceeded02_01_0_01() throws Exception {
-        doTestMaxParameterCountLimitExceeded(2, 1, 0, 1, true);
-    }
-
-
-    @Test
-    public void testMaxParameterCountLimitExceeded02_00_01_01() throws Exception {
-        doTestMaxParameterCountLimitExceeded(2, 0, 1, 1, true);
-    }
-
-
-    @Test
-    public void testMaxParameterCountLimitExceeded03_01_01_01() throws Exception {
-        doTestMaxParameterCountLimitExceeded(3, 1, 1, 1, true);
-    }
-
-
-    private void doTestMaxParameterCountLimitExceeded(int maxParameterCount, int textPartCount, int filePartCount,
-            int queryStringCount, boolean okExpected) throws Exception {
-
-        Tomcat tomcat = getTomcatInstance();
-        StandardContext ctx = (StandardContext) getProgrammaticRootContext();
-
-        ParameterLimitValve parameterLimitValve = new ParameterLimitValve();
-        ctx.getPipeline().addValve(parameterLimitValve);
-        // Only looking to test maxParameterCount
-        parameterLimitValve.setUrlPatternLimits("/upload/.*=" + Integer.toString(maxParameterCount) + ",-1,-1");
-
-        Wrapper w = Tomcat.addServlet(ctx, "multipart", new MultipartServlet());
-        // Use defaults for Multipart
-        w.setMultipartConfigElement(new MultipartConfigElement(""));
-        ctx.addServletMappingDecoded("/upload/*", "multipart");
-
-        addFailedRequestFilter(ctx);
-
-        tomcat.start();
-
-        // Construct a simple multi-part body
-        String boundary = "--simpleBoundary";
-
-        StringBuilder content = new StringBuilder();
-        int part = 1;
-
-        for (int i = 0; i < textPartCount; i++) {
-            content.append("--").append(boundary).append(CRLF);
-            content.append("Content-Disposition: form-data; name=\"part").append(part).append("\"").append(CRLF);
-            content.append(CRLF);
-            content.append("part value ").append(part).append(CRLF);
-            part++;
-        }
-
-        for (int i = 0; i < filePartCount; i++) {
-            content.append("--").append(boundary).append(CRLF);
-            content.append("Content-Disposition: form-data; name=\"part").append(part).append("\"; filename=\"part")
-                    .append(part).append("\"").append(CRLF);
-            content.append("Content-Type: text/plain").append(CRLF);
-            content.append(CRLF);
-            content.append("part value ").append(part).append(CRLF);
-            part++;
-        }
-
-        content.append("--").append(boundary).append("--").append(CRLF);
-
-        StringBuilder queryString = new StringBuilder();
-        for (int i = 0; i < queryStringCount; i++) {
-            if (i > 0) {
-                queryString.append("&");
-            }
-            queryString.append("param");
-            queryString.append(part);
-            queryString.append("=value");
-            queryString.append(part);
-            part++;
-        }
-
-
-        Map<String,List<String>> reqHeaders = new HashMap<>();
-        reqHeaders.put("Content-Type", List.of("multipart/form-data; boundary=" + boundary));
-        reqHeaders.put("Content-Length", List.of(Integer.toString(content.length())));
-
-        int rc = postUrl(content.toString().getBytes(), "http://localhost:" + getPort() + "/upload/endpoint?" +
-                queryString.toString(), new ByteChunk(), reqHeaders, null);
-
-        if (okExpected) {
-            Assert.assertEquals(HttpServletResponse.SC_OK, rc);
-        } else {
-            Assert.assertTrue(Integer.toString(rc),
-                    rc == HttpServletResponse.SC_BAD_REQUEST || rc == HttpServletResponse.SC_REQUEST_ENTITY_TOO_LARGE ||
-                    rc == HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
-        }
-    }
-
     private static class MultipartServlet extends HttpServlet {
 
         private static final long serialVersionUID = 1L;
@@ -654,22 +518,10 @@ public class TestParameterLimitValve extends TomcatBaseTest {
         @Override
         protected void doPost(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
             resp.setContentType("text/plain");
-            resp.setCharacterEncoding("UTF-8");
+            resp.setCharacterEncoding(StandardCharsets.UTF_8);
             PrintWriter pw = resp.getWriter();
-            pw.println("Parts: " + req.getParts().size());
             pw.println("Parameters: " + req.getParameterMap().size());
+            pw.println("Parts: " + req.getParts().size());
         }
     }
-
-
-    private static void addFailedRequestFilter(Context context) {
-        FilterDef failedRequestFilter = new FilterDef();
-        failedRequestFilter.setFilterName("failedRequestFilter");
-        failedRequestFilter.setFilterClass(FailedRequestFilter.class.getName());
-        FilterMap failedRequestFilterMap = new FilterMap();
-        failedRequestFilterMap.setFilterName("failedRequestFilter");
-        failedRequestFilterMap.addURLPatternDecoded("/*");
-        context.addFilterDef(failedRequestFilter);
-        context.addFilterMap(failedRequestFilterMap);
-    }
 }
